@@ -1270,7 +1270,7 @@ css_matcher_apply_rule (HtmlDocument *document, HtmlStyle *style, HtmlStyle *par
 		break;
 
 	case HTML_ATOM_TEXT_ALIGN: {
-		HtmlTextAlignType type = parent_style->inherited->text_align;
+		HtmlTextAlignType type = HTML_TEXT_ALIGN_DEFAULT;
 		switch (val->v.atom) {
 		case HTML_ATOM_INHERIT:
 			type = parent_style->inherited->text_align;
@@ -2461,8 +2461,6 @@ css_matcher_html_to_css (HtmlDocument *document, HtmlStyle *style, xmlNode *n)
 	if (n->type != XML_ELEMENT_NODE)
 		return;
 
-	if (n->properties == NULL)
-		return;
 
 	if (strcasecmp (n->name, "td") == 0 ||
 	    strcasecmp (n->name, "th") == 0) {
@@ -2498,6 +2496,9 @@ css_matcher_html_to_css (HtmlDocument *document, HtmlStyle *style, xmlNode *n)
 			node = dom_Node__get_parentNode (node);
 		}
 	}
+
+	if (n->properties == NULL)
+		return;
 	
 	if (strcasecmp (n->name, "table") == 0) {
 
