@@ -178,7 +178,9 @@ html_document_node_inserted_traverser (HtmlDocument *document, DomNode *node)
 		else if (node->xmlnode->type == XML_TEXT_NODE && node->xmlnode->parent && strcasecmp (node->xmlnode->parent->name, "textarea") == 0) {
 			dom_HTMLTextAreaElement__set_defaultValue (DOM_HTML_TEXT_AREA_ELEMENT (dom_Node__get_parentNode (node)), node->xmlnode->content);
 		}
-		else if (node->xmlnode->type == XML_TEXT_NODE && node->xmlnode->parent && strcasecmp (node->xmlnode->parent->name, "style") == 0) {
+		else if ((node->xmlnode->type == XML_TEXT_NODE || node->xmlnode->type == XML_COMMENT_NODE) && 
+				node->xmlnode->parent && strcasecmp (node->xmlnode->parent->name, "style") == 0) {
+
 			CssStylesheet *ss;
 			HtmlStyleChange style_change;
 			
@@ -189,8 +191,8 @@ html_document_node_inserted_traverser (HtmlDocument *document, DomNode *node)
 			style_change = html_document_restyle_node (document, DOM_NODE (dom_Document__get_documentElement (document->dom_document)), NULL, TRUE);
 			g_signal_emit (G_OBJECT (document), document_signals [STYLE_UPDATED], 0, DOM_NODE (dom_Document__get_documentElement (document->dom_document)), style_change);
 		}
-		else if (node->xmlnode->type == XML_TEXT_NODE && node->xmlnode->parent && strcasecmp (node->xmlnode->parent->name, "script") == 0) {
-			g_print ("whee, we have a script: len %d\n", strlen (node->xmlnode->content));
+		else if ((node->xmlnode->type == XML_TEXT_NODE || node->xmlnode->type == XML_COMMENT_NODE) && node->xmlnode->parent && strcasecmp (node->xmlnode->parent->name, "script") == 0) {
+			/*g_print ("whee, we have a script: len %d\n", strlen (node->xmlnode->content));*/
 		}
 		else if (node->xmlnode->type == XML_TEXT_NODE && node->xmlnode->parent && strcasecmp (node->xmlnode->parent->name, "title") == 0) {
 				g_signal_emit (G_OBJECT (document), document_signals [TITLE_CHANGED], 0, node->xmlnode->content);
@@ -218,7 +220,7 @@ html_document_node_inserted_traverser (HtmlDocument *document, DomNode *node)
 				xmlFree (href);
 			}
 		}
-
+		
 		if (DOM_IS_HTML_ELEMENT (node))
 			dom_html_element_parse_html_properties (DOM_HTML_ELEMENT (node), document);
 
@@ -356,9 +358,7 @@ html_document_dom_event (DomEventListener *listener, DomEvent *event, HtmlDocume
 		if (encoding)
 			g_free (encoding);
 	}
-	else 
-		g_print ("Got an event of type: %s\n", type);
-	
+
 	g_free (type);
 }
 
@@ -397,7 +397,6 @@ html_document_parsed_document_node (HtmlParser *parser, DomDocument *dom_documen
 static void
 html_document_done_parsing (HtmlParser *parser, HtmlDocument *document)
 {
-	g_print ("finally done parsing!\n");
 }
 
 static void
@@ -917,8 +916,6 @@ find_anchor_helper (DomNode *node, const gchar *anchor)
 
 		if (strcasecmp (name, anchor) == 0) {
 
-			g_print ("find_anchor_helper, found %p\n", node);
-
 			xmlFree (name);
 			return node;
 		}
