@@ -26,7 +26,7 @@ html_style_get_gtk_style (void)
 			style = gtk_style_new ();
                 }
         }
-      
+
         return style;
 }
 
@@ -233,6 +233,23 @@ html_default_style_new (void)
 	return result;
 }
 
+static void
+html_style_notify_settings (GObject *obj, GParamSpec *pspec)
+{
+	if (strcmp (pspec->name, "gtk-theme-name") == 0) {
+		HtmlColor *color;
+
+		/*
+		 * Update the default color
+		 */
+		color =  html_style_get_default_text_color ();
+		default_style->inherited->color->red =  color->red;
+		default_style->inherited->color->green =  color->green;
+		default_style->inherited->color->blue =  color->blue;
+		g_free (color);
+	}
+}
+                            
 HtmlStyle *
 html_style_new (HtmlStyle *parent)
 {
@@ -240,6 +257,10 @@ html_style_new (HtmlStyle *parent)
 
 	if (!default_style) {
 		default_style = html_default_style_new ();
+		g_signal_connect (gtk_settings_get_default (),
+				  "notify",
+				  G_CALLBACK (html_style_notify_settings),
+				  NULL);
 	}
 
 	/* FIXME: Eeeek, very ugly */
