@@ -1262,6 +1262,15 @@ html_view_get_type (void)
 	return type;
 }
 
+void
+html_view_style_set (GtkWidget *widget, GtkStyle *previous_style)
+{
+	if (previous_style) {
+ 		widget->style->bg[GTK_STATE_NORMAL] =
+ 			widget->style->base[GTK_STATE_NORMAL];
+	}
+}
+
 GtkWidget *
 html_view_new (void)
 {
@@ -1271,6 +1280,11 @@ html_view_new (void)
  	gtk_layout_set_hadjustment (GTK_LAYOUT (view), NULL);
  	gtk_layout_set_vadjustment (GTK_LAYOUT (view), NULL);
 
+	g_signal_connect (G_OBJECT (view),
+			  "style-set",
+			  G_CALLBACK (html_view_style_set),
+			  NULL);
+
 	return GTK_WIDGET (view);
 }
 
